@@ -103,7 +103,8 @@ const SearchProvider = new Lang.Class({
             ret.push({ name: new GLib.Variant('s', name),
                        id: new GLib.Variant('s', identifiers[i]),
                        description: new GLib.Variant('s', summary),
-                       icon: (new Gio.ThemedIcon({ name: 'gnome-characters' })).serialize()
+                       icon: (new Gio.ThemedIcon({ name: 'gnome-characters' })).serialize(),
+                       clipboardText: new GLib.Variant('s', character)
                      });
         }
 
